==> assertj-build-3.25.3.tar.gz: assertj-assertj-build-3.25.3/assertj-core/src/test/java/org/assertj/core/api/Condition_describedAs_Description_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2024 the original author or authors.
 */
package org.assertj.core.api;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.test.TestData.someTextDescription;

import org.assertj.core.description.Description;
import org.assertj.core.internal.TestDescription;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

/**
 * Tests for <code>{@link Condition#describedAs(Description)}</code>.
 * 
 * @author Yvonne Wang
 */
class Condition_describedAs_Description_Test {

  private static Description description;

  @BeforeAll
  static void setUpOnce() {
    description = new TestDescription(someTextDescription());
  }

  private Condition<Object> condition;

  @BeforeEach
  void setUp() {
    condition = new TestCondition<>();
  }

  @Test
  void should_set_description() {
    condition.describedAs(description);
    assertThat(condition.description()).isSameAs(description);
  }

  @Test
  void should_set_empty_description_if_description_is_null() {
    String message = null;
    condition.describedAs(message);
    assertThat(condition.description.value()).isEmpty();
  }

  @Test
  void should_return_same_condition() {
    Condition<Object> returnedCondition = condition.describedAs(description);
    assertThat(returnedCondition).isSameAs(condition);
  }
}

==> assertj-build-3.27.6.tar.gz: assertj-assertj-build-3.27.6/assertj-core/src/test/java/org/assertj/core/api/Condition_describedAs_Description_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2025 the original author or authors.
 */
package org.assertj.core.api;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.testkit.TestData.someTextDescription;

import org.assertj.core.description.Description;
import org.assertj.core.internal.TestDescription;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

/**
 * Tests for <code>{@link Condition#describedAs(Description)}</code>.
 * 
 * @author Yvonne Wang
 */
class Condition_describedAs_Description_Test {

  private static Description description;

  @BeforeAll
  static void setUpOnce() {
    description = new TestDescription(someTextDescription());
  }

  private Condition<Object> condition;

  @BeforeEach
  void setUp() {
    condition = new TestCondition<>();
  }

  @Test
  void should_set_description() {
    condition.describedAs(description);
    assertThat(condition.description()).isSameAs(description);
  }

  @Test
  void should_set_empty_description_if_description_is_null() {
    String message = null;
    condition.describedAs(message);
    assertThat(condition.description.value()).isEmpty();
  }

  @Test
  void should_return_same_condition() {
    Condition<Object> returnedCondition = condition.describedAs(description);
    assertThat(returnedCondition).isSameAs(condition);
  }
}
